@echo off
REM
REM ADSLib.bat: Process nuclear data files for ADS lib.
REM
REM Author: D. L. Aldama, IAEA/NDS Consultant
REM Date: 07/2005
REM
REM Description: It runs NJOY code for generating the ACE and
REM              MATXS files for ADS.
REM
REM Called procedures: NjoyADS.bat
REM Called programs: njispl
REM                  UpdXSDIR
REM                  njoy
REM                  gets
REM
REM Usage: ADSLib p1 l1 [m1 m2 m3 ... mn]
REM         p1: type of calculation
REM               p = pendf calculation
REM               a = acer calculation
REM               m = multigroup calculation
REM               f = full (p+a+m)
REM               q = (a+m) calculation
REM         l1:  merged evaluated nuclear data library id
REM                Ex. jeff31 for jeff31nt.dat and jeff31sl.dat
REM                    endfb6 for endfb6nt.dat and endfb6sl.dat
REM    [m1 m2 m3 ... mn]: Material id
REM                Ex. U_235, TH232, H_001
REM                if blank, all njoy inputs available are processed
REM
REM  Ex. ADSLib f jeff31 O_016
REM      ADSLib q adseva Fe056 Fe057 U_234
REM      ADSLib f adseva                 
REM
REM Setting environment variables
REM
   set njoyd=\aldama\njoy99\
   set inputd=\aldama\ADS\inputs\
   set progd=\aldama\ADS\programs\
   set pendfd=\aldama\ADS\PENDF\
   set matxsd=\aldama\ADS\MATXS\
   set aced=\aldama\ADS\ACE\
   set outd=\aldama\ADS\OUT\
REM
REM  Initializing internal variables
REM
   set opt=f
   set elib=
REM
REM Header
REM
   echo ***** Processing Nuclear Data Files for ADS *****
   date/T
   time/T
REM
REM Getting input parameters
REM
   if %1.==. goto ini
   if %1.==p. set opt=p
   if %1.==a. set opt=a
   if %1.==m. set opt=m
   if %1.==q. set opt=q
   if %1.==P. set opt=p
   if %1.==A. set opt=a
   if %1.==M. set opt=m
   if %1.==Q. set opt=q
   shift
   if %1.==. goto ini
   set elib=%1
   if not exist %inputd%%elib%NT.DAT echo %inputd%%elib%NT.DAT not found
   if not exist %inputd%%elib%NT.DAT goto end
   if not exist %inputd%%elib%NJI.INP echo %inputd%%elib%NJI.INP not found
   if not exist %inputd%%elib%NJI.INP goto end
   copy %inputd%%elib%NT.DAT tape20
   copy %inputd%%elib%NJI.INP adsnji.inp
   if %opt%.==p. goto slaw
   if %opt%.==f. goto slaw
   goto ini
:slaw
   if not exist %inputd%%elib%SL.DAT echo %inputd%%elib%SL.DAT not found
   if not exist %inputd%%elib%SL.DAT goto end
   copy %inputd%%elib%SL.DAT tape60
:ini
   if not exist tape20 echo Tape20 not found
   if not exist tape20 goto end
   if not exist adsnji.inp echo adsnji.inp not found
   if not exist adsnji.inp goto end
   if %opt%.==p. goto chk60
   if %opt%.==f. goto chk60
   goto start
:chk60
   if not exist tape60 echo Tape60 not found
   if not exist tape60 goto end
:start
   if exist *.NJI del *.NJI
   if exist inp.  del inp.
   echo adsnji.inp  >inp.
   echo.           >>inp.
   %progd%njispl<inp.
   if exist inp. del inp.
   if exist nji.lst del nji.lst
   shift
   if not %1.==. goto dowhile
   dir /B/ON ?????p.NJI >nji1.lst
   %progd%gets<nji1.lst >nji.lst
   if exist nji1.lst del nji1.lst
   goto exec
:dowhile
   echo %1 >>nji.lst
   shift
   if %1.==. goto exec
   goto dowhile
:exec
    for /F "delims=. " %%i in (nji.lst) do call %progd%NjoyADS %%i %opt%
    if exist nji.lst del nji.lst
:end
    set njoyd=
    set inputd=
    set progd=
    set pendfd=
    set matxsd=
    set aced=
    set outd=
    set elib=
    set opt=
REM
REM Done
REM
    echo.
    date/T
    time/T
    echo ***** Job ended *****
